const express = require('express')
const Env = require('ahau-env')
const path = require('path')

module.exports = {
  init (ssb, config) {
    const supportedTribes = new Set(config?.pataka?.supportedTribes)

    if (supportedTribes.size) {
      // limit responses to queries to only some tribes

      ssb.profile.findByGroupId.hook(function (findByGroupId, args) {
        const [groupId, opts, cb] = args

        if (!supportedTribes.has(groupId)) {
          return cb(null, { public: [], private: [] })
          // HACK this is an output which currently gets a tribe ignored
          // see: @ssb-graphql/profile/src/ssb/query/get-tribes.js
        }

        findByGroupId.call(this, groupId, opts, cb)
      })
    }

    if (Env().isDevelopment) return
    // In development, we assume web-registration is run by dev-server
    // Disable this line if you want to NOT use the dev server in dev-mode

    const app = express()
    const port = (config.pataka?.webRegistration?.port) || 8000

    app.use(express.static(path.join(__dirname, '../ui/dist')))

    app.listen(port)

    console.log('web-registration running on port', port)

    ssb.close.hook((close, args) => {
      close(...args)
      app.close()
    })
  }
}
